A Python and Command-Line Interface to Archive.org
==================================================

.. image:: https://travis-ci.org/jjjake/internetarchive.svg
    :target: https://travis-ci.org/jjjake/internetarchive

This package installs a command-line tool named ``ia`` for using Archive.org from the command-line.
It also installs the ``internetarchive`` Python module for programatic access to archive.org.
Please report all bugs and issues on `Github <https://github.com/jjjake/ia-wrapper/issues>`__.


Installation
------------

You can install this module via pip:

.. code:: bash

    $ pip install internetarchive

Binaries of the command-line tool are also available:

.. code:: bash

    $ curl -LO https://archive.org/download/ia-pex/ia
    $ chmod +x ia
    $ ./ia help


Documentation
-------------

Documentation is available at `https://internetarchive.readthedocs.io <https://internetarchive.readthedocs.io>`_.


Contributing
------------

All contributions are welcome and appreciated. Please see `https://internetarchive.readthedocs.io/en/latest/contributing.html <https://internetarchive.readthedocs.io/en/latest/contributing.html>`_ for more details.
